DROP TEMPORARY TABLE IF EXISTS SwissProt2Mid;
CREATE TEMPORARY TABLE IF NOT EXISTS  SwissProt2Mid
SELECT DISTINCT dbprimary_acc, stable_id
FROM mus_musculus_core_44_36e.xref, mus_musculus_core_44_36e.gene, mus_musculus_core_44_36e.gene_stable_id
WHERE external_db_id=2200 
and xref_id=display_xref_id 
and gene.gene_id=gene_stable_id.gene_id
UNION DISTINCT
SELECT DISTINCT dbprimary_acc, stable_id
FROM mus_musculus_core_44_36e.xref, mus_musculus_core_44_36e.transcript, mus_musculus_core_44_36e.gene, mus_musculus_core_44_36e.gene_stable_id 
WHERE external_db_id=2200 
AND xref_id=transcript.display_xref_id 
AND gene.gene_id=transcript.gene_id 
AND gene.gene_id=gene_stable_id.gene_id;

DROP TEMPORARY TABLE IF EXISTS UniGene2Mid;
CREATE TEMPORARY TABLE IF NOT EXISTS UniGene2Mid
SELECT DISTINCT dbprimary_acc, stable_id 
FROM mus_musculus_core_44_36e.xref, 
     mus_musculus_core_44_36e.object_xref, 
     mus_musculus_core_44_36e.transcript, 
     mus_musculus_core_44_36e.gene_stable_id 
WHERE external_db_id=4100 
and object_xref.xref_id=xref.xref_id 
and transcript.transcript_id=object_xref.ensembl_id 
and gene_stable_id.gene_id=transcript.gene_id;

DROP TEMPORARY TABLE IF EXISTS Tomap;
CREATE TEMPORARY TABLE IF NOT EXISTS Tomap
(mouse_id VARCHAR(32) PRIMARY KEY)
SELECT DISTINCT stable_id as mouse_id
FROM SwissProt2Mid
UNION DISTINCT SELECT DISTINCT stable_id as mouse_id
FROM UniGene2Mid;

DROP TEMPORARY TABLE IF EXISTS mouse_homolog;
CREATE TEMPORARY TABLE IF NOT EXISTS mouse_homolog
   (member_id int UNIQUE,
    stable_id VARCHAR(32) UNIQUE)
SELECT DISTINCT member_id, map.stable_id
FROM Tomap 
JOIN mus_musculus_core_44_36e.gene_stable_id mus 
  ON mus.stable_id=Tomap.mouse_id
JOIN ensembl_compara_44.member map
  ON mus.stable_id=map.stable_id;

DROP TEMPORARY TABLE IF EXISTS human_homolog;
CREATE TEMPORARY TABLE IF NOT EXISTS human_homolog
   (member_id int UNIQUE,
    stable_id VARCHAR(32) UNIQUE)
SELECT DISTINCT member_id, map.stable_id
FROM homo_sapiens_core_44_36f.gene_stable_id hum
JOIN ensembl_compara_44.member map
ON hum.stable_id=map.stable_id;

DROP TEMPORARY TABLE IF EXISTS homolog_member;
CREATE TEMPORARY TABLE IF NOT EXISTS homolog_member
   (member_id int PRIMARY KEY,
    stable_id VARCHAR(32) UNIQUE)
SELECT * FROM mouse_homolog
UNION DISTINCT
SELECT * FROM human_homolog;

DROP TEMPORARY TABLE IF EXISTS ortologs;
CREATE TEMPORARY TABLE IF NOT EXISTS ortologs
 (homology_id int,
  member_id int,
  INDEX (homology_id),
  INDEX (member_id))
SELECT DISTINCT h.homology_id, a.member_id
FROM homology h
JOIN ensembl_compara_44.homology_member b USING (homology_id)
JOIN homolog_member a USING (member_id)
WHERE description!="between_species_paralog"
and description!="within_species_paralog";

DROP TEMPORARY TABLE IF EXISTS Families;
CREATE TEMPORARY TABLE IF NOT EXISTS Families
SELECT DISTINCT m.stable_id, b.homology_id
FROM mouse_homolog m JOIN ortologs b USING (member_id);

#DROP TEMPORARY TABLE IF EXISTS mouse2human;
#CREATE TEMPORARY TABLE mouse2human
#(mouse VARCHAR(32),
#human VARCHAR(32),
#INDEX (mouse),
#INDEX (human))
SELECT DISTINCT b.stable_id as mouse, d.stable_id as human
FROM Families b
JOIN ortologs c      ON b.homology_id=c.homology_id
JOIN human_homolog d ON c.member_id=d.member_id;

#SELECT DISTINCT dbprimary_acc as swissprot, human
#FROM SwissProt2Mid
#JOIN mouse2human ON stable_id=mouse;

#SELECT DISTINCT dbprimary_acc as unigene, human
#FROM UniGene2Mid
#JOIN mouse2human ON stable_id=mouse;
