CREATE TABLE allset1
  (Assay_Name VARCHAR(128),
  INDEX (Assay_Name, Probe_ID, Gene_ID, Sample_Name),
   Row FLOAT,
   Col FLOAT,
   Probe_ID VARCHAR(128),
   Probe_Type TEXT,
   Gene_ID VARCHAR(128),
   X FLOAT,
   Y FLOAT,
   Assay_Normalized_Signal FLOAT,
   Signal FLOAT,
   CL_Sig FLOAT,
   CL_Raw FLOAT,
   SDEV FLOAT,
   CV FLOAT,
   S_N FLOAT,
   CL_Sig_Error FLOAT,
   CL_Raw_SDEV FLOAT,
   Flags INT,
   Sample_Name VARCHAR(128),
   id INT AUTO_INCREMENT PRIMARY KEY);
  
LOAD DATA LOCAL INFILE 'imports/all-set1.ab.csv'
INTO TABLE allset1;

# Some tables had still newline characters embedded in there sample_name
# The allset1 table had sample names that ended with something unwanted
# we resolved this by trimming them
REPLACE allset1 
SELECT
Assay_name,row,col,probe_id,probe_type,gene_id,x,y,assay_normalized_signal,signal,cl_sig,cl_raw,sdev,cv,s_n,cl_sig_error,cl_raw_sdev,flags,
Trim('\r' FROM sample_name),id
FROM allset1;

SELECT 'allset1' as `table`, COUNT(*) as `count`
FROM allset1;

CREATE TABLE allset2
     (Assay_Name TEXT,
      Probe_ID TEXT,
      Gene_ID TEXT,
      Sample_Name TEXT,
      Image_Area TEXT,
      Folder_Name TEXT,
      Folder_Type TEXT,
      Folder_Description TEXT,
      ExperimentalType TEXT,
      ExperimentalFactors TEXT,
      HybridizationReference TEXT,
      HybridizationDesign TEXT,
      QualitySteps TEXT,
      Supplement TEXT,
      Assay_Date_Time TEXT,
      Assay_description TEXT,
      Microarray_Barcode TEXT,
      Microarray_Lot_No TEXT,
      Microarray_Type TEXT,
      Microarray_Part_No TEXT);
  
LOAD DATA LOCAL INFILE 'imports/all-set2.ab.csv'
INTO TABLE allset2;
CREATE TABLE allset3
(     Assay_Name TEXT,
      Probe_ID TEXT,
      Gene_ID TEXT,
      Sample_Name TEXT,
      Sample_External_ID TEXT,
      Species TEXT,
      Tissue TEXT,
      Evironmental_Conditions TEXT,
      Disease_Name TEXT,
      Disease_State TEXT,
      Treatment_Name TEXT,
      Treatment_Type TEXT,
      Treatment_Time TEXT,
      Treatment_Concentration TEXT,
      Treatment_Chemical TEXT,
      Treatment_Mass TEXT,
      Strain_ID TEXT,
      Strain_Name TEXT,
      Tissue_Weight TEXT,
      Tissue_Extraction_Treatment TEXT,
      Titration_Dose TEXT,
      Cycle_State TEXT,
      Text_1 TEXT,
      Text_2 TEXT,
      Text_3 TEXT,
      Text_4 TEXT,
      Text_5 TEXT,
      Numeric_1 TEXT,
      Numeric_2 TEXT,
      Numeric_3 TEXT,
      Numeric_4 TEXT,
      Numeric_5 TEXT);
 
LOAD DATA LOCAL INFILE 'imports/all-set3.ab.csv'
INTO TABLE allset3;
CREATE TABLE allset4
     (Assay_Name TEXT,
      Probe_ID TEXT,
      Gene_ID TEXT,
      Sample_Name TEXT,
      Genome TEXT,
      Chromosome_Number TEXT,
      Cytoband TEXT,
      EC TEXT,
      GB_Accession TEXT,
      GO_Biological_Process TEXT,
      GO_Cellular_Component TEXT,
      GO_Molecular_Function TEXT,
      Gene_Name TEXT,
      Gene_Product TEXT,
      Gene_Symbol TEXT,
      LocusLink_ID TEXT,
      OMIM TEXT,
      Orthologs TEXT);  
  
LOAD DATA LOCAL INFILE 'imports/all-set4.ab.csv'
INTO TABLE allset4;
CREATE TABLE allset5
 (Assay_Name TEXT,
 Probe_ID TEXT,
 Gene_ID TEXT,
 Sample_Name TEXT,
 Panther_Family_Name TEXT,
 Panther_Function TEXT,
 Panther_Process TEXT,
 Panther_Subfamily_Name TEXT,
 PubMed TEXT,
 RefSeq_NM TEXT,
 RefSeq_NP TEXT,
 Riken_cDNA TEXT);
 
LOAD DATA LOCAL INFILE 'imports/all-set5.ab.csv'
INTO TABLE allset5;
CREATE TABLE allset6
(Assay_Name VARCHAR(128),
Probe_ID VARCHAR(128),
Gene_ID VARCHAR(128),
Sample_Name VARCHAR(128),
  INDEX (Assay_Name, Probe_ID, Gene_ID, Sample_Name),
Status TEXT,
SwissProt TEXT,
UniGene TEXT,
dbEST TEXT,
hCG TEXT,
hCP TEXT,
hCT TEXT,
mCG TEXT,
mCP TEXT,
mCT TEXT,
rCG TEXT,
rCP TEXT,
rCT TEXT);

LOAD DATA LOCAL INFILE 'imports/all-set6.ab.csv'
INTO TABLE allset6;


# The creation of distinct tables for the various FkRp experiments
CREATE TABLE FkrpSiRna1
SELECT allset1.Gene_ID, Assay_Normalized_Signal
FROM allset6, allset1
WHERE
(allset6.Sample_Name="1-1" 
or allset6.Sample_Name="2-1"
or allset6.Sample_Name="3-1")
and allset6.sample_name=allset1.sample_name
and allset1.Assay_Name=allset6.Assay_Name
and allset1.gene_id=allset6.gene_id
and allset1.Probe_ID=allset6.Probe_ID;

CREATE TABLE FkrpSiRna2
SELECT allset1.Gene_ID, Assay_Normalized_Signal
FROM allset6, allset1
WHERE
(allset6.Sample_Name="1-2" 
or allset6.Sample_Name="2-2")
and allset6.sample_name=allset1.sample_name
and allset1.Assay_Name=allset6.Assay_Name
and allset1.gene_id=allset6.gene_id
and allset1.Probe_ID=allset6.Probe_ID;

CREATE TABLE FkrpScrambled
SELECT allset1.Gene_ID, Assay_Normalized_Signal
FROM allset6, allset1
WHERE
(allset6.Sample_Name="1-3" 
or allset6.Sample_Name="2-3"
or allset6.Sample_Name="3-3")
and allset6.sample_name=allset1.sample_name
and allset1.Assay_Name=allset6.Assay_Name
and allset1.gene_id=allset6.gene_id
and allset1.Probe_ID=allset6.Probe_ID;


# Just dump some counts
SELECT 'allset2' as `table`, COUNT(*) as `count`
FROM allset2;
SELECT 'allset3' as `table`, COUNT(*) as `count`
FROM allset3;
SELECT 'allset4' as `table`, COUNT(*) as `count`
FROM allset4;
SELECT 'allset5' as `table`, COUNT(*) as `count`
FROM allset5;
SELECT 'allset6' as `table`, COUNT(*) as `count`
FROM allset6;
